diff --git a/Flow.Launcher.Plugin/Query.cs b/Flow.Launcher.Plugin/Query.cs
index 615729b61..3ee44f6b6 100644
--- a/Flow.Launcher.Plugin/Query.cs
+++ b/Flow.Launcher.Plugin/Query.cs
@@ -31,9 +31,10 @@ namespace Flow.Launcher.Plugin
///
/// Determines whether the query was forced to execute again.
+ /// For example, the value will be true when the user presses Ctrl + R.
/// When this property is true, plugins handling this query should avoid serving cached results.
///
- public bool IsForced { get; internal set; } = false;
+ public bool IsReQuery { get; internal set; } = false;
///
/// Search part of a query.
diff --git a/Flow.Launcher/ViewModel/MainViewModel.cs b/Flow.Launcher/ViewModel/MainViewModel.cs
index c051cd3d1..a0c1e8479 100644
--- a/Flow.Launcher/ViewModel/MainViewModel.cs
+++ b/Flow.Launcher/ViewModel/MainViewModel.cs
@@ -756,8 +756,8 @@ namespace Flow.Launcher.ViewModel
if (currentCancellationToken.IsCancellationRequested)
return;
- // Update the query's IsForced property to true if this is a re-query
- query.IsForced = reQuery;
+ // Update the query's IsReQuery property to true if this is a re-query
+ query.IsReQuery = reQuery;
// handle the exclusiveness of plugin using action keyword
RemoveOldQueryResults(query);